pyramid_royal
=============

Pyramid extension for writing RESTful web applications using traversal.

For more information on traversal algorithm, refer to `Pyramid documentation
<http://docs.pylonsproject.org/projects/pyramid/en/latest/narr/traversal.html>`_

* https://github.com/hadrien/pyramid_royal
* .. image:: https://travis-ci.org/hadrien/pyramid_royal.png?branch=master
     :target: https://travis-ci.org/hadrien/pyramid_royal
